@@ -5,9 +5,10 @@ import json
 from abc import ABC, abstractmethod
 from typing import Any, AsyncIterator
 
-from sqlsaber.database.connection import (
+from sqlsaber.database import (
     BaseDatabaseConnection,
     CSVConnection,
+    DuckDBConnection,
     MySQLConnection,
     PostgreSQLConnection,
     SQLiteConnection,
@@ -51,14 +52,16 @@ class BaseSQLAgent(ABC):
         elif isinstance(self.db, SQLiteConnection):
             return "SQLite"
         elif isinstance(self.db, CSVConnection):
-            return "SQLite"  # we convert csv to in-memory sqlite
+            return "DuckDB"
+        elif isinstance(self.db, DuckDBConnection):
+            return "DuckDB"
         else:
             return "database"  # Fallback
 
     def _init_tools(self) -> None:
         """Initialize SQL tools with database connection."""
         # Get all SQL tools and set their database connection
-        for tool_name in tool_registry.list_tools(category="sql"):
+        for tool_name in tool_registry.list_tools():
             tool = tool_registry.get_tool(tool_name)
             if isinstance(tool, SQLTool):
                 tool.set_connection(self.db)
