@@ -44,7 +44,7 @@ def setup():
             api_key_manager=api_key_manager,
             allow_oauth=True,
             default_provider="anthropic",
-            run_oauth_in_thread=False,
+            run_oauth_in_thread=True,  # questionary's sync prompts need their own event loop
         )
         return success, provider
 
@@ -167,7 +167,9 @@ def reset():
             pass
         except Exception as e:
             console.print(f"Warning: Could not remove API key: {e}", style="warning")
-            logger.warning("auth.reset.api_key_remove_failed", provider=provider, error=str(e))
+            logger.warning(
+                "auth.reset.api_key_remove_failed", provider=provider, error=str(e)
+            )
 
     # Optionally clear global auth method if removing Anthropic OAuth configuration
     if provider == "anthropic" and oauth_present:
