@@ -1,8 +1,6 @@
 """SQLSaber tools module."""
 
 from .base import Tool
-from .enums import ToolCategory, WorkflowPosition
-from .instructions import InstructionBuilder
 from .registry import ToolRegistry, register_tool, tool_registry
 
 # Import concrete tools to register them
@@ -10,12 +8,9 @@ from .sql_tools import ExecuteSQLTool, IntrospectSchemaTool, ListTablesTool, SQL
 
 __all__ = [
     "Tool",
-    "ToolCategory",
-    "WorkflowPosition",
     "ToolRegistry",
     "tool_registry",
     "register_tool",
-    "InstructionBuilder",
     "SQLTool",
     "ListTablesTool",
     "IntrospectSchemaTool",
